@@ -1,7 +1,19 @@
 # _*_ coding: utf-8 _*_
 import logging
 import re
-from typing import Dict, List, Optional, Pattern, Set, Text, Tuple, Union, cast
+from typing import (
+    TYPE_CHECKING,
+    Dict,
+    List,
+    Optional,
+    Pattern,
+    Set,
+    Text,
+    Tuple,
+    Type,
+    Union,
+    cast,
+)
 from urllib.parse import unquote_plus
 
 from multidict import MultiDict, MultiDictProxy
@@ -165,6 +177,9 @@ class SearchContext(object):
             values: List = list()
             self.normalize_param_value(raw_value, sp, values)
 
+            if len(values) == 0:
+                # empty parameters are not considered an error, they should be ignored
+                continue
             if len(values) == 1:
                 param_value_ = values[0]
             else:
@@ -179,7 +194,10 @@ class SearchContext(object):
         self, raw_value: Union[List, str], search_param: SearchParameter, container
     ):
         """ """
-        if isinstance(raw_value, list):
+        if not raw_value:
+            return
+
+        elif isinstance(raw_value, list):
             bucket: List[str] = list()
             for rv in raw_value:
                 self.normalize_param_value(rv, search_param, bucket)
@@ -718,8 +736,12 @@ class Search(object):
             # we need normalization
             klass_name = path_.context.type_class.fhir_type_name()
             if klass_name == "Reference":
-                path_ = path_ / "reference"
-                term_factory = self.create_term
+                if modifier == "identifier":
+                    path_ = path_ / "identifier"
+                    term_factory = self.create_identifier_term
+                else:
+                    path_ = path_ / "reference"
+                    term_factory = self.create_term
             elif klass_name == "Identifier":
                 term_factory = self.create_identifier_term
             elif klass_name in ("Quantity", "Duration"):
@@ -1651,11 +1673,18 @@ class AsyncSearch(Search):
         return self.response(main_result, all_includes, as_json)
 
 
-def fhir_search(context, query_string=None, params=None):
+def fhir_search(
+    context: SearchContext,
+    query_string: str = None,
+    params: Union[Dict[str, str], Tuple[Tuple[str, str]]] = None,
+    response_as_dict: bool = False,
+):
     """ """
+    if TYPE_CHECKING:
+        klass: Union[Type[AsyncSearch], Type[Search]]
     if context.async_result:
         klass = AsyncSearch
     else:
         klass = Search
     factory = klass(context, query_string=query_string, params=params)
-    return factory()
+    return factory(as_json=response_as_dict)
